==> haskell-zeromq4-haskell-0.8.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zeromq4-haskell
version:              0.8.0
visibility:           public
id:                   zeromq4-haskell-0.8.0-GwMjIo2WQ1MFj3xndDdCv3
key:                  zeromq4-haskell-0.8.0-GwMjIo2WQ1MFj3xndDdCv3
license:              MIT
copyright:            (c) 2010 - 2015 zeromq-haskell authors
maintainer:           Toralf Wittner <tw@dtex.org>
author:               Toralf Wittner
stability:            experimental
homepage:             https://gitlab.com/twittner/zeromq-haskell/
synopsis:             Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:             System, FFI
abi:                  e04a4587bafe533ecdf798cc6c0b3ba1
exposed:              True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:          /usr/lib/ghc-9.2.8/site-local/zeromq4-haskell-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zeromq4-haskell-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zeromq4-haskell
hs-libraries:         HSzeromq4-haskell-0.8.0-GwMjIo2WQ1MFj3xndDdCv3
extra-libraries:      zmq
include-dirs:         /usr/include/p11-kit-1 /usr/include/pgm-5.3
depends:
    async-2.2.5-C7wSBqUZtbTIGwzJcB5Zmf base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 exceptions-0.10.4
    monad-control-1.0.3.1-KkiVgTEnLVC11MeWLR38S0 transformers-0.5.6.2
    transformers-base-0.4.6-45h98xivtL09XO75PbjM38

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:         /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zeromq4-haskell-0.8.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zeromq4-haskell
version:              0.8.0
visibility:           public
id:                   zeromq4-haskell-0.8.0-6FLGEJNe0o15uJPmBwdjnA
key:                  zeromq4-haskell-0.8.0-6FLGEJNe0o15uJPmBwdjnA
license:              MIT
copyright:            (c) 2010 - 2015 zeromq-haskell authors
maintainer:           Toralf Wittner <tw@dtex.org>
author:               Toralf Wittner
stability:            experimental
homepage:             https://gitlab.com/twittner/zeromq-haskell/
synopsis:             Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:             System, FFI
abi:                  1ab83251121accf060cacbcde9c797b6
exposed:              True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:          /usr/lib/ghc-9.2.8/site-local/zeromq4-haskell-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zeromq4-haskell-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zeromq4-haskell
hs-libraries:         HSzeromq4-haskell-0.8.0-6FLGEJNe0o15uJPmBwdjnA
extra-libraries:      zmq
include-dirs:         /usr/include/p11-kit-1 /usr/include/pgm-5.3
depends:
    async-2.2.5-4JGZT0Ph9Ej3DBYAmeojJP base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 exceptions-0.10.4
    monad-control-1.0.3.1-YAlQIPBQdw5oAKljKUnWq transformers-0.5.6.2
    transformers-base-0.4.6-95fSAM6u0E239aFE2zowjK

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:         /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
